function aogeom(varargin);
%
% Usage: aogeom
% Description: Start a Matlab GUI that assists in defining and saving
%    an adaptive optics configuration.
%
dmglobal;
dmdefaul;

%
% now to define the gui objects.
%
% set color scheme
%
deffig = get(0, 'default');
colordef black

%
% main menu
%
gui_main=figure('name','AOGeom: WaveTrain v2000.11',...
                'numbertitle', 'off',...
                'MenuBar', 'none',...
                'WindowButtonDownFcn', 'dmbdown',...
                'WindowButtonUpFcn', 'dmbup',...
                'WindowButtonMotionFcn', 'dmbmove',...
                'color', 'black');

file_menu = uimenu('Label', 'File');
uimenu(file_menu,'Label','Load...', 'callback', 'dmgtname(''load'')');
uimenu(file_menu,'Label','Save As...', 'callback', 'dmgtname(''save'')');
uimenu(file_menu,'Label','Define Geometry...',...
                 'callback', 'dmwindon(''gui_rectangle'')',...
                 'Separator','on');
uimenu(file_menu,'Label','Print (on white)', 'callback', 'dmprint(0)', 'Separator', 'on');
uimenu(file_menu,'Label','Print (on black)', 'callback', 'dmprint(1)');
uimenu(file_menu,'Label','Quit', 'Separator','on',...
                 'callback','dmclose');


display_options_menu = uimenu('Label', 'View');
guio_disp_subaper = uimenu(display_options_menu, 'Label', 'Hide Subaperture Radius',...
                                                 'callback', 'dmsetopt(1)');
guio_disp_master = uimenu(display_options_menu, 'Label', 'Hide Master Actuator Radius',...
                                                'callback', 'dmsetopt(2)');
guio_disp_slave = uimenu(display_options_menu, 'Label', 'Hide Slave Actuator Radius',...
                                               'callback', 'dmsetopt(3)');
guio_disp_inert = uimenu(display_options_menu, 'Label', 'Hide Inert Actuator Radius',...
                                               'callback', 'dmsetopt(4)');
guio_disp_clamp = uimenu(display_options_menu, 'Label', 'Hide Clamping Radius',...
                                               'callback', 'dmsetopt(5)');
guio_disp_axes = uimenu(display_options_menu, 'Label', 'Hide Axes',...
                                              'callback', 'dmsetopt(6)');
guio_disp_nums = uimenu(display_options_menu, 'Label', 'Show Actuator Numbers',...
                                              'callback', 'dmsetopt(7)');
guio_disp_slaves = uimenu(display_options_menu, 'Label', 'Show Slave Relationships',...
                                                'callback', 'dmsetopt(8)');
guio_disp_counts = uimenu(display_options_menu, 'Label', 'Show Counts',...
                                                'callback', 'dmsetopt(9)');
                                                
help_menu = uimenu('Label', 'Help');
uimenu(help_menu, 'Label', 'Help', 'callback', 'dmhelp');

% Rectangular geometry window

grec_scale = [1/500,1/300,1/500,1/300];
phold = get(gui_main,'position');
phold = [phold(1)+40, phold(2)-40, 500, 390];
gui_rectangle = figure('position', phold,...
                       'MenuBar', 'none',...
                       'visible', 'off',...
                       'name', 'AO Geometry Parameters',...
                       'numbertitle', 'off',...
                       'color', 'black');
grec_ax = axes('visible','off','position',[0,0,1,1]);

line([10,245,245,10,10]/500, [290,290,95,95,290]/300, 'Color', 'White');
line([255,490,490,255,255]/500, [290,290,95,95,290]/300, 'Color', 'White');
line([10,490,490,10,10]/500, [85,85,30,30,85]/300, 'Color', 'White');
set(grec_ax,'xlim',[0,1],'ylim',[0,1]);

uicontrol('style','text',...
          'string','Actuator Geometry',...
          'BackgroundColor', [0.8, 0.8, 0.8], ...
          'HorizontalAlignment', 'Center',...
          'Fontunits', 'points',...
          'Fontsize', 10,...
          'Fontweight', 'bold',...
          'units', 'normalized',...
          'position', [40,282,160,16].*grec_scale);

uicontrol('style','text',...
          'string', 'Actuators/Axis',...
          'HorizontalAlignment', 'Center',...
          'units', 'normalized',...
          'position', [20,262,90,16].*grec_scale);

guid_act_num = uicontrol('style','edit',...
                         'units','normalized',...
                         'position',[120,262,120,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'Act. Spacing (m)',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [20,242,90,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'x:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [120,242,20,16].*grec_scale);

guid_act_spacing(1) = uicontrol('style', 'edit',...
                                'units', 'normalized',...
                                'position', [140,242,40,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'y:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [180,242,20,16].*grec_scale);

guid_act_spacing(2) = uicontrol('style', 'edit',...
                                'units', 'normalized',...
                                'position', [200,242,40,16].*grec_scale);
                                
uicontrol('style', 'text',...
          'string', 'Actuator Offset (N/2+1)',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [20,222,90,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'x:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [120,222,20,16].*grec_scale);

guid_act_offset(1) = uicontrol('style', 'edit',...
                               'units', 'normalized',...
                               'position', [140,222,40,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'y:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [180,222,20,16].*grec_scale);

guid_act_offset(2) = uicontrol('style', 'edit',...
                               'units', 'normalized',...
                               'position', [200,222,40,16].*grec_scale);   

uicontrol('style', 'text',...
          'string', 'Center Offset',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [20,202,90,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'x:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [120,202,20,16].*grec_scale);

guid_act_center_offset(1) =  uicontrol('style', 'edit',...
                                       'units', 'normalized',...
                                       'position', [140,202,40,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'y:',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [180,202,20,16].*grec_scale);

guid_act_center_offset(2) = uicontrol('style', 'edit',...
                                      'units', 'normalized',...
                                      'position', [200,202,40,16].*grec_scale);   

%
% Title labels for columns
%
uicontrol('style', 'text',...
          'string', 'Inner Rad.',...
          'HorizontalAlignment', 'Left',...
          'Fontunits', 'points',...
          'units', 'normalized',...
          'position', [120,182,58,16].*grec_scale);

uicontrol('style', 'text',...
          'string', 'Outer Rad.',...
          'HorizontalAlignment', 'Left',...
          'Fontunits', 'points',...
          'units', 'normalized',...
          'position', [182,182,58,16].*grec_scale);

%
% Title labels for rows
%
uicontrol('style', 'text',...
          'string', 'Master Actuators',...
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [20,162,90,16].*grec_scale);
uicontrol('style', 'text',...              
          'string', 'Slave Actuators',...       
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position',[20,142,90,16].*grec_scale);
uicontrol('style', 'text',...              
          'string', 'Inert Actuators',...       
          'HorizontalAlignment', 'Left',...
          'units', 'normalized',...
          'position', [20,122,90,16].*grec_scale);

%
% Creating a grid of TextFields:
%
for i = 1:3
  for j = 1:2
    guid_act_radii(i,j) = uicontrol('style', 'edit',...
                                    'units', 'normalized',...
                                    'position', [120+62*(j-1), 162-(i-1)*20, 58, 16].*grec_scale);
  end;
end;

guid_slave_corners_three_ways = uicontrol('style', 'checkbox',...
                                          'String', 'Slave Corners Three Ways',...
                                          'units', 'normalized',...
                                          'position', [20,102,220,16].*grec_scale);

%
% Finishing an Actuator Geometry Box
%

%
%Creating a WFS Subaperture Box
%
uicontrol('style','text',...
          'string','Subaperture Geometry',...
          'BackgroundColor', [0.8, 0.8, 0.8], ...
          'HorizontalAlignment', 'Left',...
          'Fontunits', 'points',...
          'Fontsize', 10,...
          'Fontweight', 'bold',...
          'units','normalized',...
          'position',[280,282,160,16].*grec_scale);
                                           
uicontrol('style','text',...              
          'string','Subaps./Axis',...     
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,262,90,16].*grec_scale);
          
guiw_act_num = uicontrol('style','edit',...
                         'units','normalized',...
                         'position',[360,262,120,16].*grec_scale);

uicontrol('style','text',...              
          'string','Subap. Offset',...    
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,242,90,16].*grec_scale);
                                           
uicontrol('style','text',...              
          'string','x:',...               
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[360,242,20,16].*grec_scale);
          
guiw_subaper_offset(1) = uicontrol('style','edit',...
                                   'units','normalized',...
                                   'position',[380,242,40,16].*grec_scale);
                                   
uicontrol('style','text',...              
          'string','y:',...               
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[420,242,20,16].*grec_scale);
          
guiw_subaper_offset(2) = uicontrol('style','edit',...
                                   'units','normalized',...
                                   'position',[440,242,40,16].*grec_scale);
                                           
uicontrol('style','text',...              
          'string','Subap. Spacing',...   
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,222,90,16].*grec_scale);
          
guiw_subaper_space = uicontrol('style','edit',...
                               'units','normalized',...
                               'position',[360,222,120,16].*grec_scale);

uicontrol('style','text',...              
          'string','Subap. Outer Rad.',...   
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,182,90,16].*grec_scale);
          
guiw_subaper_clip = uicontrol('style','edit',...
                              'units','normalized',...
                              'position',[360,182,120,16].*grec_scale);

uicontrol('style','text',...              
          'string','Subap. Inner Rad.',...   
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,162,90,16].*grec_scale);
          
guiw_subaper_anulus = uicontrol('style','edit',...
                                'units','normalized',...
                                'position',[360,162,120,16].*grec_scale);

uicontrol('style','text',...
          'string','# of Integ Steps/Side of SubAp',...
          'HorizontalAlignment', 'Left',...
          'units','normalized',...
          'position',[260,142,90,16].*grec_scale);
          
guiw_num_steps = uicontrol('style','edit',...
                           'units','normalized',...
                           'position',[360,142,120,16].*grec_scale);

guiw_full_only = uicontrol('style','checkbox',...
                           'string','Full Subapertures Only',...
                           'units','normalized',...
                           'position',[260,102,220,16].*grec_scale);

%
% Finishing a WFS Subaperture Geometry Box
%


%
% Creating an InfluenceFunction Box
%

uicontrol('style','text',...
          'string','Influence Function',...
          'BackgroundColor', [0.8, 0.8, 0.8], ...
          'HorizontalAlignment', 'Center',...
          'Fontunits', 'points',...
          'Fontsize', 10,...
          'Fontweight', 'bold',...
          'units','normalized',...
          'position',[170,82,160,16].*grec_scale);

guii_function = zeros(1,5);

guii_function(1) = uicontrol('style','radio',...
                             'string','Green''s Function',...
                             'units','normalized',...
                             'position',[30,62,80,16].*grec_scale,...
                             'userdata',str2mat('Clamping Radius','Actuator Influence Reach'));
                             
guii_function(2) = uicontrol('style','radio',...
                             'string','Gaussian',...
                             'units','normalized',...
                             'position',[120,62,80,16].*grec_scale,...
                             'userdata',str2mat('X Half Width','Y Half Width'));
                             
guii_function(3) = uicontrol('style','radio',...
                             'string','Piston',...
                             'units','normalized',...
                             'position',[210,62,80,16].*grec_scale,...
                             'userdata',str2mat('X Radius','Y Radius'));
                             
guii_function(4) = uicontrol('style','radio',...
                             'string','Linear',...
                             'units','normalized',...
                             'position',[300,62,80,16].*grec_scale,...
                             'userdata',str2mat('X Radius','Y Radius'));
                             
guii_function(5) = uicontrol('style','radio',...
                             'string','Cubic',...
                             'units','normalized',...
                             'position',[390,62,80,16].*grec_scale,...
                             'userdata',str2mat('X Radius','Y Radius'));

set(guii_function,'callback','dmclinfl');

tempstr = get(guii_function(dm_influence),'userdata');

guii_infl_label(1) = uicontrol('style','text',...
                               'string', tempstr(1,:),...
                               'HorizontalAlignment', 'Left',...
                               'units','normalized',...
                               'position',[20,42,120,16].*grec_scale);
                               
guii_infl_label(2) = uicontrol('style','text',...
                               'string', tempstr(2,:),...
                               'HorizontalAlignment', 'Left',...
                               'units','normalized',...
                               'position',[260,42,120,16].*grec_scale);

guii_infl_width(1) = uicontrol('style','edit',...
                               'units','normalized',...
                               'position',[150,42,90,16].*grec_scale);
   
guii_infl_width(2) = uicontrol('style','edit',...
                               'units','normalized',...
                               'position',[390,42,90,16].*grec_scale);

%
% Finishing an InfluenceFunction Box
%

%
% Ok and Cancel pushButtons
%
uicontrol('style','pushbutton',...
          'string','OK',...
          'units','normalized',...
          'position',[20,02,100,16].*grec_scale,...
          'callback','dmsetval, set(gcf,''visible'',''off''), dmplot(1)');

uicontrol('style','pushbutton',...
          'string','Apply',...
          'units','normalized',...
          'position',[140,02,100,16].*grec_scale,...
          'callback', 'dmsetval, dmplot(1)' );

uicontrol('style','pushbutton',...
          'string','Reset',...
          'units','normalized',...
          'position',[260,02,100,16].*grec_scale,...
          'callback', 'dmdefaul; dmreset; if (exist(''defaocfg.mat'',''file'')); dmload(''defaocfg.mat''); end; dmplot(1)' );

uicontrol('style','pushbutton',...
          'string','Cancel',...
          'units','normalized',...
          'position',[380,02,100,16].*grec_scale,...
          'callback','dmreset, set(gcf,''visible'',''off'')');

gui_box = 0;

%
% if we were passed a filename, load it.
%
if (nargin > 0)
   dmload(varargin{1});
   dmplot(0);
else
   dmreset;
   if (exist('defaocfg.mat','file'))
      dmload('defaocfg.mat')
   end;
   dmplot(1);
end

%
% Set the defaults back to what they were before the routine
% was called.
%
set(0, deffig);

